@@ -484,7 +484,7 @@ def defineDoubleTrap(rise, top, tau, length=None):
 	boxcar[0] = -1
 	boxcar[rise+top] = 1
 	doubleTrap = np.convolve(singleTrap, boxcar)
-	if doubleTrap < length:
+	if len(doubleTrap) < length:
 		out = np.zeros(length)
 		out[:len(doubleTrap)] = doubleTrap[:]
 		return out
@@ -620,7 +620,7 @@ def emulateDAQFilter(waves, rise, top, tau, triggerThreshold):
 				waves = da.asarray(waves)
 			#figure out the scale factor
 			scaleFactor = int(1.0/Fxp(1.0/(float(tau) * float(rise)), signed=False, n_word=24, n_frac=23))
-			filteredWaves = da.apply_along_axis(daqFilterEmulator, waves, rise, top, tau, scaleFactor).compute()
+			filteredWaves = da.apply_along_axis(daqFilterEmulator, 1, waves, rise, top, tau, scaleFactor).compute()
 			return filteredWaves
 		else:
 			print('fxpmath library not available. This is required for this function.')
